import os
import sys
import os.path as path
import argparse

import numpy as np
import polyscope as ps
import igl

import meshgen_tools



def main():

    parser = argparse.ArgumentParser()

    # Build arguments
    parser.add_argument('mesh', type=str, help='path to a mesh')
    parser.add_argument('ind', type=int, help='source vertex')

    # Parse arguments
    args = parser.parse_args()

    ps.init()

    # Load mesh arg
    poly_V, poly_faces_flat, poly_faces_size = meshgen_tools.load_mesh_poly_flat(args.mesh)

    # triangulate
    F_tri = meshgen_tools.triangulate_polygons_flat_list(poly_V, poly_faces_flat, poly_faces_size)
    
    if args.ind >= poly_V.shape[0]:
        raise ValueError(f"vertex index {args.ind} is out of bounds for nVerts={poly_V.shape[0]}")
   
    ps_mesh = ps.register_surface_mesh("mesh", poly_V, F_tri)
    # ps.show()

    # Exact algorithm
    # dists = igl.exact_geodesic(poly_V, F_tri, np.array([args.ind]).astype(np.int32), np.arange(poly_V.shape[0]).astype(np.int32)) 

    # Heat algorithm
    dists = meshgen_tools.heat_method_distance(poly_V, F_tri, args.ind)

    ps_mesh.add_scalar_quantity("dists", dists, enabled=True, isolines_enabled=True)

    ps.show()

if __name__ == '__main__':
    main()
